==> form-utils-react-hooks-0.0.4.tgz: package/esm/hooks/register/register.FormHideItem.js <==
import * as __WEBPACK_EXTERNAL_MODULE_react__ from "react";
import * as __WEBPACK_EXTERNAL_MODULE__carefrees_form_utils_f42d2666__ from "@carefrees/form-utils";
import * as __WEBPACK_EXTERNAL_MODULE__useFormItemParentName_js_a729dfb1__ from "../useFormItemParentName.js";
import * as __WEBPACK_EXTERNAL_MODULE__useForm_js_2c14e707__ from "../useForm.js";
import * as __WEBPACK_EXTERNAL_MODULE__useUpdate_js_b5f1687a__ from "../useUpdate.js";
const useRegisterFormHideItem = (options)=>{
    const { name, sort, isJoinParentField = true } = options;
    const form = (0, __WEBPACK_EXTERNAL_MODULE__useForm_js_2c14e707__.useFormInstance)();
    const _update = (0, __WEBPACK_EXTERNAL_MODULE__useUpdate_js_b5f1687a__.useUpdate)();
    const { newName, newSort } = (0, __WEBPACK_EXTERNAL_MODULE__useFormItemParentName_js_a729dfb1__.useFormItemParentName)({
        name,
        sort,
        isJoinParentField
    });
    const hideItemInstance = (0, __WEBPACK_EXTERNAL_MODULE_react__.useRef)(new __WEBPACK_EXTERNAL_MODULE__carefrees_form_utils_f42d2666__.FormHideItemInstanceBase().ctor(newName)).current;
    const isHide = form.getFieldHideValue(newName);
    hideItemInstance.instance = form;
    hideItemInstance.updated = _update.current;
    hideItemInstance.sort = newSort;
    (0, __WEBPACK_EXTERNAL_MODULE_react__.useEffect)(()=>{
        const unMount = form.registerFormHideItem(hideItemInstance);
        return ()=>unMount();
    }, [
        newName
    ]);
    return {
        form,
        isHide
    };
};
export { useRegisterFormHideItem };

==> form-utils-react-hooks-0.0.9.tgz: package/esm/hooks/register/register.FormHideItem.js <==
import * as __WEBPACK_EXTERNAL_MODULE_react__ from "react";
import * as __WEBPACK_EXTERNAL_MODULE__carefrees_form_utils_f42d2666__ from "@carefrees/form-utils";
import * as __WEBPACK_EXTERNAL_MODULE__useFormItemParentName_js_a729dfb1__ from "../useFormItemParentName.js";
import * as __WEBPACK_EXTERNAL_MODULE__useForm_js_2c14e707__ from "../useForm.js";
const useRegisterFormHideItem = (options)=>{
    const { name, sort, isJoinParentField = true } = options;
    const form = (0, __WEBPACK_EXTERNAL_MODULE__useForm_js_2c14e707__.useFormInstance)();
    const [, setValue] = (0, __WEBPACK_EXTERNAL_MODULE_react__.useState)({});
    const { newName, newSort } = (0, __WEBPACK_EXTERNAL_MODULE__useFormItemParentName_js_a729dfb1__.useFormItemParentName)({
        name,
        sort,
        isJoinParentField
    });
    const hideItemInstance = (0, __WEBPACK_EXTERNAL_MODULE_react__.useRef)(new __WEBPACK_EXTERNAL_MODULE__carefrees_form_utils_f42d2666__.FormHideItemInstanceBase().ctor(newName)).current;
    const isHide = form.getFieldHideValue(newName);
    hideItemInstance.preHideValue = isHide;
    hideItemInstance.instance = form;
    hideItemInstance.updatedItem = setValue;
    hideItemInstance.sort = newSort;
    (0, __WEBPACK_EXTERNAL_MODULE_react__.useEffect)(()=>{
        const unMount = form.registerFormHideItem(hideItemInstance);
        return ()=>unMount();
    }, [
        newName
    ]);
    return {
        form,
        isHide
    };
};
export { useRegisterFormHideItem };
